@@ -2,7 +2,10 @@
 from collections import defaultdict
 
 from django import template
+from django.core.urlresolvers import reverse
+from django.db.models import get_model, get_models
 
+from mezzanine.core.templatetags.mezzanine_tags import register_as_tag
 from mezzanine.pages.models import Page
 from mezzanine.settings import PAGES_MENU_SHOW_ALL
 
@@ -22,7 +25,7 @@ def _page_menu(context, parent_page):
             user = context["request"].user
         except KeyError:
             user = None
-        for page in Page.objects.published(for_user=user).order_by("ordering"):
+        for page in Page.objects.published(for_user=user).order_by("_order"):
             try:
                 slug = context["request"].path.strip("/")
             except KeyError:
@@ -50,3 +53,28 @@ def page_menu_admin(context, parent_page=None):
     """
     return _page_menu(context, parent_page)
 
+@register_as_tag(register)
+def models_for_pages(*args):
+    """
+    Create a select list containing each of the models that subclass Page
+    """
+    page_models = []
+    for model in get_models():
+        if issubclass(model, Page):
+            setattr(model, "name", model._meta.verbose_name)
+            setattr(model, "add_url", reverse("admin:%s_%s_add" % 
+                (model._meta.app_label, model.__name__.lower())))
+            page_models.append(model)
+    return page_models
+
+@register.filter
+def is_page_content_model(admin_model_dict):
+    """
+    Returns True if the model in the given admin dict is a subclass of Page.
+    """
+    args = admin_model_dict["admin_url"].strip("/").split("/")
+    if len(args) == 2:
+        model = get_model(*args)
+        return model is not Page and issubclass(model, Page)
+    return False
+
